'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = localStorageTokenStore;

var _tokenHelpers = require('./tokenHelpers');

const loadClientData = clientId => {
  const data = JSON.parse(localStorage.getItem(_tokenHelpers.storageKey));

  return data ? data[clientId] : undefined;
}; /* global localStorage, JSON */

const saveClientData = (clientId, clientData) => {
  const data = JSON.parse(localStorage.getItem(_tokenHelpers.storageKey));

  const updatedData = Object.assign({}, data, {
    [clientId]: clientData
  });

  localStorage.setItem(_tokenHelpers.storageKey, JSON.stringify(updatedData));
};

const withClientData = (clientId, update) => {
  const clientData = loadClientData(clientId);
  const updatedClientData = update(clientData);

  saveClientData(clientId, updatedClientData);
};

function localStorageTokenStore(clientId, url) {
  return {
    store(auth) {
      withClientData(clientId, clientData => Object.assign({}, clientData, {
        [url]: auth
      }));
    },

    fetch() {
      const clientData = loadClientData(clientId);

      return clientData ? clientData[url] : undefined;
    },

    clear() {
      withClientData(clientId, clientData => Object.assign({}, clientData, {
        [url]: undefined
      }));
    }
  };
}